@@ -2,7 +2,7 @@
 import requests
 from requests import Response
 
-from rowantree.common.sdk import demand_env_var
+from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
 from rowantree.contracts import UserActive
 
 from ..abstract_command import AbstractCommand
@@ -39,6 +39,6 @@ class UserActiveGetCommand(AbstractCommand):
         response: Response = requests.get(
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/active",
             headers=headers,
-            timeout=demand_env_var(name="ROWANTREE_SERVICE_TIMEOUT"),
+            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
         return UserActive.parse_obj(response.json())
