@@ -3,7 +3,7 @@
 import requests
 from requests import Response
 
-from rowantree.common.sdk import demand_env_var
+from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
 from rowantree.contracts import User
 
 from ..abstract_command import AbstractCommand
@@ -38,6 +38,6 @@ class UserCreateCommand(AbstractCommand):
         response: Response = requests.post(
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user",
             headers=headers,
-            timeout=demand_env_var(name="ROWANTREE_SERVICE_TIMEOUT"),
+            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
         return User.parse_obj(response.json())
