@@ -2,7 +2,7 @@
 
 import requests
 
-from rowantree.common.sdk import demand_env_var
+from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
 
 from ..abstract_command import AbstractCommand
 
@@ -33,5 +33,5 @@ class UserDeleteCommand(AbstractCommand):
         requests.delete(
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}",
             headers=headers,
-            timeout=demand_env_var(name="ROWANTREE_SERVICE_TIMEOUT"),
+            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
