@@ -3,7 +3,7 @@
 import requests
 from requests import Response
 
-from rowantree.common.sdk import demand_env_var
+from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
 from rowantree.contracts import UserIncomes
 
 from ..abstract_command import AbstractCommand
@@ -40,6 +40,6 @@ class UserIncomeGetCommand(AbstractCommand):
         response: Response = requests.get(
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/user/{user_guid}/income",
             headers=headers,
-            timeout=demand_env_var(name="ROWANTREE_SERVICE_TIMEOUT"),
+            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
         )
         return UserIncomes.parse_obj(response.json())
